from uuid import UUID

from sqlalchemy import text
from sqlalchemy.ext.asyncio import AsyncSession

from fastfood_two.domain.menu.menu_entity import Menu
from fastfood_two.infrastructure.pg_storage.mappers.menu_mapper import (
    db_entity_to_domain,
)


class MenuGatewayImpl:
    def __init__(self, session: AsyncSession) -> None:
        self._session = session

    async def get_all_menus(self) -> list[Menu]:
        query = text("SELECT * FROM menu;")
        menus = await self._session.execute(query)
        return [db_entity_to_domain(menu) for menu in menus]

    async def get_menu_by_id(self, id: UUID) -> Menu | None: ...

    async def insert_menu(self, menu: Menu) -> Menu:
        query = text("INSERT INTO menu (id, title, description) VALUES (:id, :title, :description);")
        await self._session.execute(
            query,
            {
                "id": menu.id.value,
                "title": menu.title.value,
                "description": menu.description.value,
            },
        )
        await self._session.commit()
        return menu

    async def update_menu(self, updated_menu: Menu) -> Menu | None: ...

    async def delete_menu(self, id: UUID) -> None: ...
